@@ -21,7 +21,9 @@ file named COPYING.  Among other things, the copyright notice
 and this notice must be preserved on all copies.  
 */
 #ifndef _Random_h
+#pragma once
 #define _Random_h 1
+#pragma once
 
 #include <math.h>
 #include "RNG.h"
@@ -31,7 +33,7 @@ protected:
     RNG *pGenerator;
 public:
     Random(RNG *generator);
-    virtual double operator()();
+    virtual double operator()() = 0;
 
     RNG *generator();
     void generator(RNG *p);
