@@ -19,23 +19,27 @@ can know your rights and responsibilities.  It should be in a
 file named COPYING.  Among other things, the copyright notice
 and this notice must be preserved on all copies.  
 */
-#ifndef ASSERTH
-#define ASSERTH
 
-#ifndef NDEBUG
-
-#include "generic.h"
-
-extern void _assert(const char *, const char *, const int);
-extern void _assert2(const char *, const char *, const int, const char *);
-
-#define assert(ex) { if ((ex)) ; else _assert( #ex, __FILE__,__LINE__); }
-#define assert2(ex,s) { if ((ex)) ; else _assert2( #ex, __FILE__,__LINE__, s); }
+/* Allow this file to be included multiple times
+   with different settings of NDEBUG.  */
+#undef assert
+#undef assertval
 
+#ifdef NDEBUG
+#define assert(ignore)
+#define assertval(ex)  (ex)
 #else
 
-#define assert(ex) 
-#define assert2(ex,s)
+extern "C" void __eprintf (char*, int, char*);		/* Defined in gnulib */
+extern "C" volatile void   abort();
+
+#define assert(ex) \
+        ((ex) ? 1 : \
+              (__eprintf("Failed assertion " #ex " at line %d of `%s'.\n", \
+               __LINE__, __FILE__), abort (), 0))
+#define assertval(ex) \
+        ((ex) ? 1 : \
+              (__eprintf("Failed assertion " #ex " at line %d of `%s'.\n", \
+               __LINE__, __FILE__), abort (), 0))
 
 #endif NDEBUG
-#endif ASSERTH
