@@ -22,37 +22,25 @@ and this notice must be preserved on all copies.
 */
 
 #ifndef _stddef_h
+#pragma once
 
 #define _stddef_h
 
-#ifndef TRUE                    // disable if already done #define TRUE 1...
-#ifndef bool
-enum bool   
-{           
-  FALSE = 0,
-  TRUE  = 1              
-};
-#endif
-#endif
+// TRUE, FALSE, bool, are now in <bool.h>, for ANSI compatibility
 
-#ifndef L_ctermid
-#define L_ctermid	9 
-#endif
-#ifndef L_cuserid
-#define L_cuserid	9
-#endif
-#ifndef P_tmpdir
-#define	P_tmpdir    "/tmp/"
-#endif
-#ifndef L_tmpnam
-#define	L_tmpnam    (sizeof(P_tmpdir) + 15)
-#endif
 
+typedef unsigned long   size_t;
+typedef long int	    ptrdiff_t;
+
+#ifdef DGUX
+typedef	int	wchar_t;
+#else
+typedef	unsigned char	wchar_t;
+#endif
 
 #ifndef NULL
-#define NULL ((void *)0)
+#define NULL 0
 #endif
 
-typedef void (*one_arg_error_handler_t)(char*);
 
 #endif
